@@ -15,6 +15,9 @@
 #
 # ##### END GPL LICENSE BLOCK #####
 
+import os
+from pathlib import Path
+
 # Constant values
 
 # Datablock
@@ -29,7 +32,7 @@ ERROR = 6
 
 # networking
 STATE_INITIAL = 0
-STATE_LAUNCHING_SERVICES = 9
+CONNECTING = 9
 STATE_WAITING = 6
 STATE_CONFIG = 4
 STATE_SYNCING = 1
@@ -42,7 +45,6 @@ STATE_LOBBY = 10
 
 # rights
 RP_COMMON = 'COMMON'
-RP_STRICT = 'STRICT'
 
 # Differential methodology
 DIFF_BINARY = 0
@@ -50,4 +52,10 @@ DIFF_JSON = 1
 
 # Default values
 CONNECTION_TIMEOUT=2000
-CLIENT_PING_FREQUENCY = 1000
\ No newline at end of file
+CLIENT_PING_FREQUENCY = 1000
+
+HEAD = 'HEAD'
+
+ROOT_PATH = Path(os.path.dirname(os.path.realpath(__file__)))
+TTL_SCRIPT_PATH = os.path.join(ROOT_PATH, 'ttl.py')
+SERVER_SCRIPT_PATH = os.path.join(ROOT_PATH, 'server.py')
\ No newline at end of file
